[Libreoffice-commits] core.git: 3 commits - cui/source editeng/source include/editeng sw/source

Jan Holesovsky kendy at collabora.com
Tue May 26 03:20:58 PDT 2015


 cui/source/inc/autocdlg.hxx         |    4 +--
 cui/source/tabpages/autocdlg.cxx    |   30 ++++++++++++-------------
 editeng/source/editeng/impedit2.cxx |    6 ++---
 editeng/source/misc/acorrcfg.cxx    |   12 +++++-----
 editeng/source/misc/svxacorr.cxx    |   42 ++++++++++++++++++------------------
 editeng/source/misc/swafopt.cxx     |    4 +--
 include/editeng/svxacorr.hxx        |   12 +++++-----
 include/editeng/swafopt.hxx         |    2 -
 sw/source/core/edit/acorrect.cxx    |    8 +++---
 sw/source/core/edit/autofmt.cxx     |   10 ++++----
 sw/source/core/inc/acorrect.hxx     |    4 +--
 sw/source/uibase/docvw/edtwin.cxx   |    4 +--
 sw/source/uibase/shells/textsh.cxx  |    2 -
 sw/source/uibase/wrtsh/wrtsh1.cxx   |    2 -
 14 files changed, 71 insertions(+), 71 deletions(-)

New commits:
commit 26092f54865645722aeed596af62d20918aa2046
Author: Jan Holesovsky <kendy at collabora.com>
Date:   Tue May 26 09:56:37 2015 +0200

    CptlSttSent -> CapitalStartSentence.
    
    Change-Id: If9de3512c4ec6070652541c40d263afcb2a7a305

diff --git a/cui/source/inc/autocdlg.hxx b/cui/source/inc/autocdlg.hxx
index a972b90..b016220 100644
--- a/cui/source/inc/autocdlg.hxx
+++ b/cui/source/inc/autocdlg.hxx
@@ -133,7 +133,7 @@ class OfaSwAutoFmtOptionsPage : public SfxTabPage
     OUString        sDeleteEmptyPara;
     OUString        sUseReplaceTbl;
     OUString        sCapitalStartWord;
-    OUString        sCptlSttSent;
+    OUString        sCapitalStartSentence;
     OUString        sUserStyle;
     OUString        sBullet;
     OUString        sBoldUnder;
diff --git a/cui/source/tabpages/autocdlg.cxx b/cui/source/tabpages/autocdlg.cxx
index abbe7ae..a4da64e 100644
--- a/cui/source/tabpages/autocdlg.cxx
+++ b/cui/source/tabpages/autocdlg.cxx
@@ -416,7 +416,7 @@ OfaSwAutoFmtOptionsPage::OfaSwAutoFmtOptionsPage( vcl::Window* pParent,
     , sDeleteEmptyPara(CUI_RESSTR(RID_SVXSTR_DEL_EMPTY_PARA))
     , sUseReplaceTbl(CUI_RESSTR(RID_SVXSTR_USE_REPLACE))
     , sCapitalStartWord(CUI_RESSTR(RID_SVXSTR_CPTL_STT_WORD))
-    , sCptlSttSent(CUI_RESSTR(RID_SVXSTR_CPTL_STT_SENT))
+    , sCapitalStartSentence(CUI_RESSTR(RID_SVXSTR_CPTL_STT_SENT))
     , sUserStyle(CUI_RESSTR(RID_SVXSTR_USER_STYLE))
     , sBullet(CUI_RESSTR(RID_SVXSTR_BULLET))
     , sBoldUnder(CUI_RESSTR(RID_SVXSTR_BOLD_UNDER))
@@ -650,8 +650,8 @@ void OfaSwAutoFmtOptionsPage::Reset( const SfxItemSet* )
     // The following entries have to be inserted in the same order
     // as in the OfaAutoFmtOptions-enum!
     m_pCheckLB->GetModel()->Insert(CreateEntry(sUseReplaceTbl,     CBCOL_BOTH  ));
-    m_pCheckLB->GetModel()->Insert(CreateEntry(sCapitalStartWord,       CBCOL_BOTH  ));
-    m_pCheckLB->GetModel()->Insert(CreateEntry(sCptlSttSent,       CBCOL_BOTH  ));
+    m_pCheckLB->GetModel()->Insert(CreateEntry(sCapitalStartWord,  CBCOL_BOTH  ));
+    m_pCheckLB->GetModel()->Insert(CreateEntry(sCapitalStartSentence, CBCOL_BOTH  ));
     m_pCheckLB->GetModel()->Insert(CreateEntry(sBoldUnder,         CBCOL_BOTH  ));
     m_pCheckLB->GetModel()->Insert(CreateEntry(sDetectURL,         CBCOL_BOTH  ));
     m_pCheckLB->GetModel()->Insert(CreateEntry(sDash,              CBCOL_BOTH  ));
commit 9fadc1dc4753862a41569651cf6357234e5e3333
Author: Jan Holesovsky <kendy at collabora.com>
Date:   Tue May 26 09:52:08 2015 +0200

    Global CptlSttWrd and CptlSttWord -> CapitalStartWord
    
    Change-Id: I550456ae319a6a865f2ee951a1ddf70384ce33ef

diff --git a/cui/source/inc/autocdlg.hxx b/cui/source/inc/autocdlg.hxx
index db8bc8a..a972b90 100644
--- a/cui/source/inc/autocdlg.hxx
+++ b/cui/source/inc/autocdlg.hxx
@@ -132,7 +132,7 @@ class OfaSwAutoFmtOptionsPage : public SfxTabPage
 
     OUString        sDeleteEmptyPara;
     OUString        sUseReplaceTbl;
-    OUString        sCptlSttWord;
+    OUString        sCapitalStartWord;
     OUString        sCptlSttSent;
     OUString        sUserStyle;
     OUString        sBullet;
diff --git a/cui/source/tabpages/autocdlg.cxx b/cui/source/tabpages/autocdlg.cxx
index 27efd0f..abbe7ae 100644
--- a/cui/source/tabpages/autocdlg.cxx
+++ b/cui/source/tabpages/autocdlg.cxx
@@ -228,7 +228,7 @@ bool OfaAutocorrOptionsPage::FillItemSet( SfxItemSet* )
 
     sal_uLong nPos = 0;
     pAutoCorrect->SetAutoCorrFlag(Autocorrect,          m_pCheckLB->IsChecked(nPos++));
-    pAutoCorrect->SetAutoCorrFlag(CptlSttWrd,           m_pCheckLB->IsChecked(nPos++));
+    pAutoCorrect->SetAutoCorrFlag(CapitalStartWord,     m_pCheckLB->IsChecked(nPos++));
     pAutoCorrect->SetAutoCorrFlag(CapitalStartSentence, m_pCheckLB->IsChecked(nPos++));
     pAutoCorrect->SetAutoCorrFlag(ChgWeightUnderl,      m_pCheckLB->IsChecked(nPos++));
     pAutoCorrect->SetAutoCorrFlag(SetINetAttr,          m_pCheckLB->IsChecked(nPos++));
@@ -270,7 +270,7 @@ void OfaAutocorrOptionsPage::Reset( const SfxItemSet* )
 
     sal_uLong nPos = 0;
     m_pCheckLB->CheckEntryPos( nPos++, 0 != (nFlags & Autocorrect) );
-    m_pCheckLB->CheckEntryPos( nPos++, 0 != (nFlags & CptlSttWrd) );
+    m_pCheckLB->CheckEntryPos( nPos++, 0 != (nFlags & CapitalStartWord) );
     m_pCheckLB->CheckEntryPos( nPos++, 0 != (nFlags & CapitalStartSentence) );
     m_pCheckLB->CheckEntryPos( nPos++, 0 != (nFlags & ChgWeightUnderl) );
     m_pCheckLB->CheckEntryPos( nPos++, 0 != (nFlags & SetINetAttr) );
@@ -415,7 +415,7 @@ OfaSwAutoFmtOptionsPage::OfaSwAutoFmtOptionsPage( vcl::Window* pParent,
     : SfxTabPage(pParent, "ApplyAutoFmtPage", "cui/ui/applyautofmtpage.ui", &rSet)
     , sDeleteEmptyPara(CUI_RESSTR(RID_SVXSTR_DEL_EMPTY_PARA))
     , sUseReplaceTbl(CUI_RESSTR(RID_SVXSTR_USE_REPLACE))
-    , sCptlSttWord(CUI_RESSTR(RID_SVXSTR_CPTL_STT_WORD))
+    , sCapitalStartWord(CUI_RESSTR(RID_SVXSTR_CPTL_STT_WORD))
     , sCptlSttSent(CUI_RESSTR(RID_SVXSTR_CPTL_STT_SENT))
     , sUserStyle(CUI_RESSTR(RID_SVXSTR_USER_STYLE))
     , sBullet(CUI_RESSTR(RID_SVXSTR_BULLET))
@@ -531,9 +531,9 @@ bool OfaSwAutoFmtOptionsPage::FillItemSet( SfxItemSet*  )
                         m_pCheckLB->IsChecked(USE_REPLACE_TABLE, CBCOL_SECOND));
 
     bCheck = m_pCheckLB->IsChecked(CORR_UPPER, CBCOL_FIRST);
-    bModified |= pOpt->bCptlSttWrd != bCheck;
-    pOpt->bCptlSttWrd = bCheck;
-    pAutoCorrect->SetAutoCorrFlag(CptlSttWrd,
+    bModified |= pOpt->bCapitalStartWord != bCheck;
+    pOpt->bCapitalStartWord = bCheck;
+    pAutoCorrect->SetAutoCorrFlag(CapitalStartWord,
                         m_pCheckLB->IsChecked(CORR_UPPER, CBCOL_SECOND));
 
     bCheck = m_pCheckLB->IsChecked(BEGIN_UPPER, CBCOL_FIRST);
@@ -650,7 +650,7 @@ void OfaSwAutoFmtOptionsPage::Reset( const SfxItemSet* )
     // The following entries have to be inserted in the same order
     // as in the OfaAutoFmtOptions-enum!
     m_pCheckLB->GetModel()->Insert(CreateEntry(sUseReplaceTbl,     CBCOL_BOTH  ));
-    m_pCheckLB->GetModel()->Insert(CreateEntry(sCptlSttWord,       CBCOL_BOTH  ));
+    m_pCheckLB->GetModel()->Insert(CreateEntry(sCapitalStartWord,       CBCOL_BOTH  ));
     m_pCheckLB->GetModel()->Insert(CreateEntry(sCptlSttSent,       CBCOL_BOTH  ));
     m_pCheckLB->GetModel()->Insert(CreateEntry(sBoldUnder,         CBCOL_BOTH  ));
     m_pCheckLB->GetModel()->Insert(CreateEntry(sDetectURL,         CBCOL_BOTH  ));
@@ -671,8 +671,8 @@ void OfaSwAutoFmtOptionsPage::Reset( const SfxItemSet* )
 
     m_pCheckLB->CheckEntryPos( USE_REPLACE_TABLE,  CBCOL_FIRST,    pOpt->bAutoCorrect );
     m_pCheckLB->CheckEntryPos( USE_REPLACE_TABLE,  CBCOL_SECOND,   0 != (nFlags & Autocorrect));
-    m_pCheckLB->CheckEntryPos( CORR_UPPER,         CBCOL_FIRST,    pOpt->bCptlSttWrd );
-    m_pCheckLB->CheckEntryPos( CORR_UPPER,         CBCOL_SECOND,   0 != (nFlags & CptlSttWrd) );
+    m_pCheckLB->CheckEntryPos( CORR_UPPER,         CBCOL_FIRST,    pOpt->bCapitalStartWord );
+    m_pCheckLB->CheckEntryPos( CORR_UPPER,         CBCOL_SECOND,   0 != (nFlags & CapitalStartWord) );
     m_pCheckLB->CheckEntryPos( BEGIN_UPPER,        CBCOL_FIRST,    pOpt->bCapitalStartSentence );
     m_pCheckLB->CheckEntryPos( BEGIN_UPPER,        CBCOL_SECOND,   0 != (nFlags & CapitalStartSentence) );
     m_pCheckLB->CheckEntryPos( BOLD_UNDERLINE,     CBCOL_FIRST,    pOpt->bChgWeightUnderl );
diff --git a/editeng/source/misc/acorrcfg.cxx b/editeng/source/misc/acorrcfg.cxx
index fc746e1..a60392a 100644
--- a/editeng/source/misc/acorrcfg.cxx
+++ b/editeng/source/misc/acorrcfg.cxx
@@ -154,7 +154,7 @@ void SvxBaseAutoCorrCfg::Load(bool bInit)
                     break;//"UseReplacementTable",
                     case  3:
                         if(*static_cast<sal_Bool const *>(pValues[nProp].getValue()))
-                            nFlags |= CptlSttWrd;
+                            nFlags |= CapitalStartWord;
                     break;//"TwoCapitalsAtStart",
                     case  4:
                         if(*static_cast<sal_Bool const *>(pValues[nProp].getValue()))
@@ -263,7 +263,7 @@ void SvxBaseAutoCorrCfg::ImplCommit()
                 pValues[nProp].setValue(&bVal, rType);
             break;//"UseReplacementTable",
             case  3:
-                bVal = 0 != (nFlags & CptlSttWrd);
+                bVal = 0 != (nFlags & CapitalStartWord);
                 pValues[nProp].setValue(&bVal, rType);
             break;//"TwoCapitalsAtStart",
             case  4:
@@ -412,7 +412,7 @@ void SvxSwAutoCorrCfg::Load(bool bInit)
                     case   4: rParent.bSearchInAllCategories = *static_cast<sal_Bool const *>(pValues[nProp].getValue());  break; //"Text/SearchInAllCategories"
                     case   5: rSwFlags.bAutoCorrect = *static_cast<sal_Bool const *>(pValues[nProp].getValue()); break; // "Format/Option/UseReplacementTable",
                     case   6: rSwFlags.bCapitalStartSentence = *static_cast<sal_Bool const *>(pValues[nProp].getValue()); break; // "Format/Option/TwoCapitalsAtStart",
-                    case   7: rSwFlags.bCptlSttWrd = *static_cast<sal_Bool const *>(pValues[nProp].getValue()); break; // "Format/Option/CapitalAtStartSentence",
+                    case   7: rSwFlags.bCapitalStartWord = *static_cast<sal_Bool const *>(pValues[nProp].getValue()); break; // "Format/Option/CapitalAtStartSentence",
                     case   8: rSwFlags.bChgWeightUnderl = *static_cast<sal_Bool const *>(pValues[nProp].getValue()); break; // "Format/Option/ChangeUnderlineWeight",
                     case   9: rSwFlags.bSetINetAttr = *static_cast<sal_Bool const *>(pValues[nProp].getValue()); break; // "Format/Option/SetInetAttribute",
                     case  10: rSwFlags.bChgOrdinalNumber = *static_cast<sal_Bool const *>(pValues[nProp].getValue()); break; // "Format/Option/ChangeOrdinalNumber",
@@ -566,7 +566,7 @@ void SvxSwAutoCorrCfg::ImplCommit()
             case   4: pValues[nProp].setValue(&rParent.bSearchInAllCategories, rType );break; //"Text/SearchInAllCategories"
             case   5: bVal = rSwFlags.bAutoCorrect; pValues[nProp].setValue(&bVal, rType); break; // "Format/Option/UseReplacementTable",
             case   6: bVal = rSwFlags.bCapitalStartSentence; pValues[nProp].setValue(&bVal, rType); break; // "Format/Option/TwoCapitalsAtStart",
-            case   7: bVal = rSwFlags.bCptlSttWrd; pValues[nProp].setValue(&bVal, rType); break; // "Format/Option/CapitalAtStartSentence",
+            case   7: bVal = rSwFlags.bCapitalStartWord; pValues[nProp].setValue(&bVal, rType); break; // "Format/Option/CapitalAtStartSentence",
             case   8: bVal = rSwFlags.bChgWeightUnderl; pValues[nProp].setValue(&bVal, rType); break; // "Format/Option/ChangeUnderlineWeight",
             case   9: bVal = rSwFlags.bSetINetAttr; pValues[nProp].setValue(&bVal, rType); break; // "Format/Option/SetInetAttribute",
             case  10: bVal = rSwFlags.bChgOrdinalNumber; pValues[nProp].setValue(&bVal, rType); break; // "Format/Option/ChangeOrdinalNumber",
diff --git a/editeng/source/misc/svxacorr.cxx b/editeng/source/misc/svxacorr.cxx
index 425e687..77e0774 100644
--- a/editeng/source/misc/svxacorr.cxx
+++ b/editeng/source/misc/svxacorr.cxx
@@ -174,7 +174,7 @@ SvxAutoCorrDoc::~SvxAutoCorrDoc()
 }
 
 // Called by the functions:
-//  - FnCptlSttWrd
+//  - FnCapitalStartWord
 //  - FnCapitalStartSentence
 // after the exchange of characters. Then the words, if necessary, can be inserted
 // into the exception list.
@@ -251,7 +251,7 @@ long SvxAutoCorrect::GetDefaultFlags()
 {
     long nRet = Autocorrect
                     | CapitalStartSentence
-                    | CptlSttWrd
+                    | CapitalStartWord
                     | ChgOrdinalNumber
                     | ChgToEnEmDash
                     | AddNonBrkSpace
@@ -342,7 +342,7 @@ void SvxAutoCorrect::SetAutoCorrFlag( long nFlag, bool bOn )
     {
         if( (nOld & CapitalStartSentence) != (nFlags & CapitalStartSentence) )
             nFlags &= ~CplSttLstLoad;
-        if( (nOld & CptlSttWrd) != (nFlags & CptlSttWrd) )
+        if( (nOld & CapitalStartWord) != (nFlags & CapitalStartWord) )
             nFlags &= ~WrdSttLstLoad;
         if( (nOld & Autocorrect) != (nFlags & Autocorrect) )
             nFlags &= ~ChgWordLstLoad;
@@ -351,7 +351,7 @@ void SvxAutoCorrect::SetAutoCorrFlag( long nFlag, bool bOn )
 
 
     // Two capital letters at the beginning of word?
-bool SvxAutoCorrect::FnCptlSttWrd( SvxAutoCorrDoc& rDoc, const OUString& rTxt,
+bool SvxAutoCorrect::FnCapitalStartWord( SvxAutoCorrDoc& rDoc, const OUString& rTxt,
                                     sal_Int32 nSttPos, sal_Int32 nEndPos,
                                     LanguageType eLang )
 {
@@ -430,7 +430,7 @@ bool SvxAutoCorrect::FnCptlSttWrd( SvxAutoCorrDoc& rDoc, const OUString& rTxt,
                 if( sChar[0] != cSave && rDoc.ReplaceRange( nSttPos, 1, sChar ))
                 {
                     if( SaveWordWrdSttLst & nFlags )
-                        rDoc.SaveCpltSttWord( CptlSttWrd, nSttPos, sWord, cSave );
+                        rDoc.SaveCpltSttWord( CapitalStartWord, nSttPos, sWord, cSave );
                     bRet = true;
                 }
             }
@@ -1420,9 +1420,9 @@ SvxAutoCorrect::DoAutoCorrect( SvxAutoCorrDoc& rDoc, const OUString& rTxt,
 
             // Two capital letters at beginning of word ??
             if( !bUnsupported &&
-                IsAutoCorrFlag( CptlSttWrd ) &&
-                FnCptlSttWrd( rDoc, rTxt, nCapLttrPos, nInsPos, eLang ) )
-                nRet |= CptlSttWrd;
+                IsAutoCorrFlag( CapitalStartWord ) &&
+                FnCapitalStartWord( rDoc, rTxt, nCapLttrPos, nInsPos, eLang ) )
+                nRet |= CapitalStartWord;
 
             if( IsAutoCorrFlag( ChgToEnEmDash ) &&
                 FnChgToEnEmDash( rDoc, rTxt, nCapLttrPos, nInsPos, eLang ) )
diff --git a/editeng/source/misc/swafopt.cxx b/editeng/source/misc/swafopt.cxx
index 22910b7..f146bf5 100644
--- a/editeng/source/misc/swafopt.cxx
+++ b/editeng/source/misc/swafopt.cxx
@@ -27,7 +27,7 @@ SvxSwAutoFormatFlags::SvxSwAutoFormatFlags()
 {
     bAutoCorrect =
     bCapitalStartSentence =
-    bCptlSttWrd =
+    bCapitalStartWord =
     bChkFontAttr =
     bChgUserColl =
     bChgEnumNum =
@@ -85,7 +85,7 @@ SvxSwAutoFormatFlags& SvxSwAutoFormatFlags::operator=( const SvxSwAutoFormatFlag
 {
     bAutoCorrect = rAFFlags.bAutoCorrect;
     bCapitalStartSentence = rAFFlags.bCapitalStartSentence;
-    bCptlSttWrd = rAFFlags.bCptlSttWrd;
+    bCapitalStartWord = rAFFlags.bCapitalStartWord;
     bChkFontAttr = rAFFlags.bChkFontAttr;
 
     bChgUserColl = rAFFlags.bChgUserColl;
diff --git a/include/editeng/svxacorr.hxx b/include/editeng/svxacorr.hxx
index 3070d1a..b2f2a04 100644
--- a/include/editeng/svxacorr.hxx
+++ b/include/editeng/svxacorr.hxx
@@ -56,7 +56,7 @@ class SvStringsISortDtor
 
 // Auto correct flags
 const long CapitalStartSentence = 0x00000001;   // Capital letters at the beginning of a sentence
-const long CptlSttWrd       = 0x00000002;   // not two Capital letters at the beginning of a word
+const long CapitalStartWord = 0x00000002;   // not two Capital letters at the beginning of a word
 const long AddNonBrkSpace   = 0x00000004;   // Add non breaking space before :;?!%
 const long ChgOrdinalNumber = 0x00000008;   // Ordinal-Number 1st, 2nd,..
 const long ChgToEnEmDash    = 0x00000010;   // - -> Endash/Emdash
@@ -105,7 +105,7 @@ public:
                                   SvxAutoCorrect& rACorrect,
                                   OUString* pPara ) = 0;
     // Is called after the change of the signs by the functions
-    //  - FnCptlSttWrd
+    //  - FnCapitalStartWord
     //  - FnCapitalStartSentence
     // As an option, the words can then be inserted into the exception lists.
     virtual void SaveCpltSttWord( sal_uLong nFlag, sal_Int32 nPos,
@@ -387,7 +387,7 @@ public:
                                     bool bAbbreviation = false);
 
     // Methods for the auto-correction
-    bool FnCptlSttWrd( SvxAutoCorrDoc&, const OUString&,
+    bool FnCapitalStartWord( SvxAutoCorrDoc&, const OUString&,
                                 sal_Int32 nSttPos, sal_Int32 nEndPos,
                                 LanguageType eLang = LANGUAGE_SYSTEM );
     bool FnChgOrdinalNumber( SvxAutoCorrDoc&, const OUString&,
diff --git a/include/editeng/swafopt.hxx b/include/editeng/swafopt.hxx
index 6929228..ad29525 100644
--- a/include/editeng/swafopt.hxx
+++ b/include/editeng/swafopt.hxx
@@ -77,7 +77,7 @@ struct EDITENG_DLLPUBLIC SvxSwAutoFormatFlags
 
     bool bAutoCorrect : 1;
     bool bCapitalStartSentence : 1;
-    bool bCptlSttWrd : 1;
+    bool bCapitalStartWord : 1;
     bool bChkFontAttr : 1;
 
     bool bChgUserColl : 1;
diff --git a/sw/source/core/edit/acorrect.cxx b/sw/source/core/edit/acorrect.cxx
index 28cb796..722346a 100644
--- a/sw/source/core/edit/acorrect.cxx
+++ b/sw/source/core/edit/acorrect.cxx
@@ -402,7 +402,7 @@ bool SwAutoCorrDoc::ChgAutoCorrWord( sal_Int32& rSttPos, sal_Int32 nEndPos,
 }
 
 // Called by the functions:
-//  - FnCptlSttWrd
+//  - FnCapitalStartWord
 //  - FnCapitalStartSentence
 // after the exchange of characters. Then the words, if necessary, can be inserted
 // into the exception list.
@@ -441,7 +441,7 @@ void SwAutoCorrExceptWord::CheckChar( const SwPosition& rPos, sal_Unicode cChr )
         SvxAutoCorrect* pACorr = SvxAutoCorrCfg::Get().GetAutoCorrect();
 
         // then add to the list:
-        if (CptlSttWrd & m_nFlags)
+        if (CapitalStartWord & m_nFlags)
             pACorr->AddWrtSttException(m_sWord, m_eLanguage);
         else if (CapitalStartSentence & m_nFlags)
             pACorr->AddCplSttException(m_sWord, m_eLanguage);
diff --git a/sw/source/core/edit/autofmt.cxx b/sw/source/core/edit/autofmt.cxx
index f7013a9..7c118ca 100644
--- a/sw/source/core/edit/autofmt.cxx
+++ b/sw/source/core/edit/autofmt.cxx
@@ -1785,7 +1785,7 @@ void SwAutoFormat::AutoCorrect( sal_Int32 nPos )
 
     if( m_aFlags.bAFormatByInput ||
         (!m_aFlags.bAutoCorrect && !bReplaceQuote && !bReplaceSglQuote &&
-        !m_aFlags.bCapitalStartSentence && !m_aFlags.bCptlSttWrd &&
+        !m_aFlags.bCapitalStartSentence && !m_aFlags.bCapitalStartWord &&
         !m_aFlags.bChgOrdinalNumber &&
         !m_aFlags.bChgToEnEmDash && !m_aFlags.bSetINetAttr &&
         !m_aFlags.bChgWeightUnderl && !m_aFlags.bAddNonBrkSpace) )
@@ -1797,7 +1797,7 @@ void SwAutoFormat::AutoCorrect( sal_Int32 nPos )
 
     bool bGetLanguage = m_aFlags.bChgOrdinalNumber ||
                         m_aFlags.bChgToEnEmDash || m_aFlags.bSetINetAttr ||
-                        m_aFlags.bCptlSttWrd || m_aFlags.bCapitalStartSentence ||
+                        m_aFlags.bCapitalStartWord || m_aFlags.bCapitalStartSentence ||
                         m_aFlags.bAddNonBrkSpace;
 
     m_aDelPam.DeleteMark();
@@ -2040,10 +2040,10 @@ void SwAutoFormat::AutoCorrect( sal_Int32 nPos )
             else
             {
                 // two capital letters at the beginning of a word?
-                if( m_aFlags.bCptlSttWrd )
+                if( m_aFlags.bCapitalStartWord )
                 {
                     SetRedlineText( STR_AUTOFMTREDL_CPTL_STT_WORD );
-                    pATst->FnCptlSttWrd( aACorrDoc, *pText, nSttPos, nPos, eLang );
+                    pATst->FnCapitalStartWord( aACorrDoc, *pText, nSttPos, nPos, eLang );
                 }
                 // capital letter at the beginning of a sentence?
                 if( m_aFlags.bCapitalStartSentence && bFirst )
diff --git a/sw/source/core/inc/acorrect.hxx b/sw/source/core/inc/acorrect.hxx
index 4a833abf..f5129d9 100644
--- a/sw/source/core/inc/acorrect.hxx
+++ b/sw/source/core/inc/acorrect.hxx
@@ -79,7 +79,7 @@ public:
                                   OUString* pPara ) SAL_OVERRIDE;
 
     // Will be called after swapping characters by the functions
-    //  - FnCptlSttWrd and
+    //  - FnCapitalStartWord and
     //  - FnCapitalStartSentence.
     // Afterwards the words can be added into exception list if needed.
     virtual void SaveCpltSttWord( sal_uLong nFlag, sal_Int32 nPos,
diff --git a/sw/source/uibase/docvw/edtwin.cxx b/sw/source/uibase/docvw/edtwin.cxx
index 3db93d4..a3c5f68 100644
--- a/sw/source/uibase/docvw/edtwin.cxx
+++ b/sw/source/uibase/docvw/edtwin.cxx
@@ -2393,7 +2393,7 @@ KEYINPUT_CHECKTABLE_INSDEL:
                 }
                 else if( !aKeyEvent.GetRepeat() && pACorr && ( bIsAutoCorrectChar || bRunNext ) &&
                         pACfg->IsAutoFormatByInput() &&
-                    pACorr->IsAutoCorrFlag( CapitalStartSentence | CptlSttWrd |
+                    pACorr->IsAutoCorrFlag( CapitalStartSentence | CapitalStartWord |
                                             ChgOrdinalNumber | AddNonBrkSpace |
                                             ChgToEnEmDash | SetINetAttr |
                                             Autocorrect ) &&
@@ -2427,7 +2427,7 @@ KEYINPUT_CHECKTABLE_INSDEL:
         case KS_CheckAutoCorrect:
         {
             if( pACorr && pACfg->IsAutoFormatByInput() &&
-                pACorr->IsAutoCorrFlag( CapitalStartSentence | CptlSttWrd |
+                pACorr->IsAutoCorrFlag( CapitalStartSentence | CapitalStartWord |
                                         ChgOrdinalNumber |
                                         ChgToEnEmDash | SetINetAttr |
                                         Autocorrect ) &&
diff --git a/sw/source/uibase/shells/textsh.cxx b/sw/source/uibase/shells/textsh.cxx
index 3261a85..d2f69e1 100644
--- a/sw/source/uibase/shells/textsh.cxx
+++ b/sw/source/uibase/shells/textsh.cxx
@@ -169,7 +169,7 @@ void SwTextShell::ExecInsert(SfxRequest &rReq)
             SvxAutoCorrect* pACorr = rACfg.GetAutoCorrect();
             if( pACorr && rACfg.IsAutoFormatByInput()
                 && pACorr->IsAutoCorrFlag(
-                    CapitalStartSentence | CptlSttWrd | AddNonBrkSpace | ChgOrdinalNumber | ChgToEnEmDash | SetINetAttr | Autocorrect ) )
+                    CapitalStartSentence | CapitalStartWord | AddNonBrkSpace | ChgOrdinalNumber | ChgToEnEmDash | SetINetAttr | Autocorrect ) )
             {
                 rSh.AutoCorrect( *pACorr, cIns );
             }
diff --git a/sw/source/uibase/wrtsh/wrtsh1.cxx b/sw/source/uibase/wrtsh/wrtsh1.cxx
index 5d1c0d7..99da1d4 100644
--- a/sw/source/uibase/wrtsh/wrtsh1.cxx
+++ b/sw/source/uibase/wrtsh/wrtsh1.cxx
@@ -137,7 +137,7 @@ using namespace com::sun::star;
 static SvxAutoCorrect* lcl_IsAutoCorr()
 {
     SvxAutoCorrect* pACorr = SvxAutoCorrCfg::Get().GetAutoCorrect();
-    if( pACorr && !pACorr->IsAutoCorrFlag( CapitalStartSentence | CptlSttWrd |
+    if( pACorr && !pACorr->IsAutoCorrFlag( CapitalStartSentence | CapitalStartWord |
                             AddNonBrkSpace | ChgOrdinalNumber |
                             ChgToEnEmDash | SetINetAttr | Autocorrect ))
         pACorr = 0;
commit 42f0f1397ad6c36410e26f8bbc04372a754b153d
Author: Jan Holesovsky <kendy at collabora.com>
Date:   Tue May 26 09:49:42 2015 +0200

    Global CptlSttSntnc -> CapitalStartSentence
    
    Change-Id: Id428332201f14b172af1590baed6aa2a67e0557a

diff --git a/cui/source/tabpages/autocdlg.cxx b/cui/source/tabpages/autocdlg.cxx
index 21678fd..27efd0f 100644
--- a/cui/source/tabpages/autocdlg.cxx
+++ b/cui/source/tabpages/autocdlg.cxx
@@ -229,7 +229,7 @@ bool OfaAutocorrOptionsPage::FillItemSet( SfxItemSet* )
     sal_uLong nPos = 0;
     pAutoCorrect->SetAutoCorrFlag(Autocorrect,          m_pCheckLB->IsChecked(nPos++));
     pAutoCorrect->SetAutoCorrFlag(CptlSttWrd,           m_pCheckLB->IsChecked(nPos++));
-    pAutoCorrect->SetAutoCorrFlag(CptlSttSntnc,         m_pCheckLB->IsChecked(nPos++));
+    pAutoCorrect->SetAutoCorrFlag(CapitalStartSentence, m_pCheckLB->IsChecked(nPos++));
     pAutoCorrect->SetAutoCorrFlag(ChgWeightUnderl,      m_pCheckLB->IsChecked(nPos++));
     pAutoCorrect->SetAutoCorrFlag(SetINetAttr,          m_pCheckLB->IsChecked(nPos++));
     pAutoCorrect->SetAutoCorrFlag(ChgToEnEmDash,        m_pCheckLB->IsChecked(nPos++));
@@ -271,7 +271,7 @@ void OfaAutocorrOptionsPage::Reset( const SfxItemSet* )
     sal_uLong nPos = 0;
     m_pCheckLB->CheckEntryPos( nPos++, 0 != (nFlags & Autocorrect) );
     m_pCheckLB->CheckEntryPos( nPos++, 0 != (nFlags & CptlSttWrd) );
-    m_pCheckLB->CheckEntryPos( nPos++, 0 != (nFlags & CptlSttSntnc) );
+    m_pCheckLB->CheckEntryPos( nPos++, 0 != (nFlags & CapitalStartSentence) );
     m_pCheckLB->CheckEntryPos( nPos++, 0 != (nFlags & ChgWeightUnderl) );
     m_pCheckLB->CheckEntryPos( nPos++, 0 != (nFlags & SetINetAttr) );
     m_pCheckLB->CheckEntryPos( nPos++, 0 != (nFlags & ChgToEnEmDash) );
@@ -539,7 +539,7 @@ bool OfaSwAutoFmtOptionsPage::FillItemSet( SfxItemSet*  )
     bCheck = m_pCheckLB->IsChecked(BEGIN_UPPER, CBCOL_FIRST);
     bModified |= pOpt->bCapitalStartSentence != bCheck;
     pOpt->bCapitalStartSentence = bCheck;
-    pAutoCorrect->SetAutoCorrFlag(CptlSttSntnc,
+    pAutoCorrect->SetAutoCorrFlag(CapitalStartSentence,
                         m_pCheckLB->IsChecked(BEGIN_UPPER, CBCOL_SECOND));
 
     bCheck = m_pCheckLB->IsChecked(BOLD_UNDERLINE, CBCOL_FIRST);
@@ -674,7 +674,7 @@ void OfaSwAutoFmtOptionsPage::Reset( const SfxItemSet* )
     m_pCheckLB->CheckEntryPos( CORR_UPPER,         CBCOL_FIRST,    pOpt->bCptlSttWrd );
     m_pCheckLB->CheckEntryPos( CORR_UPPER,         CBCOL_SECOND,   0 != (nFlags & CptlSttWrd) );
     m_pCheckLB->CheckEntryPos( BEGIN_UPPER,        CBCOL_FIRST,    pOpt->bCapitalStartSentence );
-    m_pCheckLB->CheckEntryPos( BEGIN_UPPER,        CBCOL_SECOND,   0 != (nFlags & CptlSttSntnc) );
+    m_pCheckLB->CheckEntryPos( BEGIN_UPPER,        CBCOL_SECOND,   0 != (nFlags & CapitalStartSentence) );
     m_pCheckLB->CheckEntryPos( BOLD_UNDERLINE,     CBCOL_FIRST,    pOpt->bChgWeightUnderl );
     m_pCheckLB->CheckEntryPos( BOLD_UNDERLINE,     CBCOL_SECOND,   0 != (nFlags & ChgWeightUnderl) );
     m_pCheckLB->CheckEntryPos( IGNORE_DBLSPACE,    CBCOL_SECOND,   0 != (nFlags & IgnoreDoubleSpace) );
diff --git a/editeng/source/editeng/impedit2.cxx b/editeng/source/editeng/impedit2.cxx
index 7905893..f9d4131 100644
--- a/editeng/source/editeng/impedit2.cxx
+++ b/editeng/source/editeng/impedit2.cxx
@@ -2490,7 +2490,7 @@ EditPaM ImpEditEngine::AutoCorrect( const EditSelection& rCurSel, sal_Unicode c,
         // #i78661 allow application to turn off capitalization of
         // start sentence explicitly.
         // (This is done by setting IsFirstWordCapitalization to sal_False.)
-        bool bOldCptlSttSntnc = pAutoCorrect->IsAutoCorrFlag( CptlSttSntnc );
+        bool bOldCapitalStartSentence = pAutoCorrect->IsAutoCorrFlag( CapitalStartSentence );
         if (!IsFirstWordCapitalization())
         {
             ESelection aESel( CreateESel(aSel) );
@@ -2521,7 +2521,7 @@ EditPaM ImpEditEngine::AutoCorrect( const EditSelection& rCurSel, sal_Unicode c,
                     aSel.Max().GetIndex() <= aSecondWordSel.Min().GetIndex();
 
             if (bIsFirstWordInFirstPara)
-                pAutoCorrect->SetAutoCorrFlag( CptlSttSntnc, IsFirstWordCapitalization() );
+                pAutoCorrect->SetAutoCorrFlag( CapitalStartSentence, IsFirstWordCapitalization() );
         }
 
         ContentNode* pNode = aSel.Max().GetNode();
@@ -2535,7 +2535,7 @@ EditPaM ImpEditEngine::AutoCorrect( const EditSelection& rCurSel, sal_Unicode c,
 
         // #i78661 since the SvxAutoCorrect object used here is
         // shared we need to reset the value to it's original state.
-        pAutoCorrect->SetAutoCorrFlag( CptlSttSntnc, bOldCptlSttSntnc );
+        pAutoCorrect->SetAutoCorrFlag( CapitalStartSentence, bOldCapitalStartSentence );
     }
     return aSel.Max();
 }
diff --git a/editeng/source/misc/acorrcfg.cxx b/editeng/source/misc/acorrcfg.cxx
index 31e4fec..fc746e1 100644
--- a/editeng/source/misc/acorrcfg.cxx
+++ b/editeng/source/misc/acorrcfg.cxx
@@ -158,7 +158,7 @@ void SvxBaseAutoCorrCfg::Load(bool bInit)
                     break;//"TwoCapitalsAtStart",
                     case  4:
                         if(*static_cast<sal_Bool const *>(pValues[nProp].getValue()))
-                            nFlags |= CptlSttSntnc;
+                            nFlags |= CapitalStartSentence;
                     break;//"CapitalAtStartSentence",
                     case  5:
                         if(*static_cast<sal_Bool const *>(pValues[nProp].getValue()))
@@ -267,7 +267,7 @@ void SvxBaseAutoCorrCfg::ImplCommit()
                 pValues[nProp].setValue(&bVal, rType);
             break;//"TwoCapitalsAtStart",
             case  4:
-                bVal = 0 != (nFlags & CptlSttSntnc);
+                bVal = 0 != (nFlags & CapitalStartSentence);
                 pValues[nProp].setValue(&bVal, rType);
             break;//"CapitalAtStartSentence",
             case  5:
diff --git a/include/editeng/svxacorr.hxx b/include/editeng/svxacorr.hxx
index 18fb82a..3070d1a 100644
--- a/include/editeng/svxacorr.hxx
+++ b/include/editeng/svxacorr.hxx
@@ -55,7 +55,7 @@ class SvStringsISortDtor
 };
 
 // Auto correct flags
-const long CptlSttSntnc     = 0x00000001;   // Capital letters at the beginning of a sentence
+const long CapitalStartSentence = 0x00000001;   // Capital letters at the beginning of a sentence
 const long CptlSttWrd       = 0x00000002;   // not two Capital letters at the beginning of a word
 const long AddNonBrkSpace   = 0x00000004;   // Add non breaking space before :;?!%
 const long ChgOrdinalNumber = 0x00000008;   // Ordinal-Number 1st, 2nd,..
@@ -106,7 +106,7 @@ public:
                                   OUString* pPara ) = 0;
     // Is called after the change of the signs by the functions
     //  - FnCptlSttWrd
-    //  - FnCptlSttSntnc
+    //  - FnCapitalStartSentence
     // As an option, the words can then be inserted into the exception lists.
     virtual void SaveCpltSttWord( sal_uLong nFlag, sal_Int32 nPos,
                                     const OUString& rExceptWord,
@@ -405,7 +405,7 @@ public:
     bool FnChgWeightUnderl( SvxAutoCorrDoc&, const OUString&,
                                 sal_Int32 nSttPos, sal_Int32 nEndPos,
                                 LanguageType eLang = LANGUAGE_SYSTEM );
-    bool FnCptlSttSntnc( SvxAutoCorrDoc&, const OUString&, bool bNormalPos,
+    bool FnCapitalStartSentence( SvxAutoCorrDoc&, const OUString&, bool bNormalPos,
                                 sal_Int32 nSttPos, sal_Int32 nEndPos,
                                 LanguageType eLang  = LANGUAGE_SYSTEM);
     bool FnCorrectCapsLock( SvxAutoCorrDoc&, const OUString&,
diff --git a/sw/source/core/edit/acorrect.cxx b/sw/source/core/edit/acorrect.cxx
index 82255be..28cb796 100644
--- a/sw/source/core/edit/acorrect.cxx
+++ b/sw/source/core/edit/acorrect.cxx
@@ -403,7 +403,7 @@ bool SwAutoCorrDoc::ChgAutoCorrWord( sal_Int32& rSttPos, sal_Int32 nEndPos,
 
 // Called by the functions:
 //  - FnCptlSttWrd
-//  - FnCptlSttSntnc
+//  - FnCapitalStartSentence
 // after the exchange of characters. Then the words, if necessary, can be inserted
 // into the exception list.
 void SwAutoCorrDoc::SaveCpltSttWord( sal_uLong nFlag, sal_Int32 nPos,
@@ -443,7 +443,7 @@ void SwAutoCorrExceptWord::CheckChar( const SwPosition& rPos, sal_Unicode cChr )
         // then add to the list:
         if (CptlSttWrd & m_nFlags)
             pACorr->AddWrtSttException(m_sWord, m_eLanguage);
-        else if (CptlSttSntnc & m_nFlags)
+        else if (CapitalStartSentence & m_nFlags)
             pACorr->AddCplSttException(m_sWord, m_eLanguage);
     }
 }
diff --git a/sw/source/core/edit/autofmt.cxx b/sw/source/core/edit/autofmt.cxx
index 75cb288..f7013a9 100644
--- a/sw/source/core/edit/autofmt.cxx
+++ b/sw/source/core/edit/autofmt.cxx
@@ -2049,7 +2049,7 @@ void SwAutoFormat::AutoCorrect( sal_Int32 nPos )
                 if( m_aFlags.bCapitalStartSentence && bFirst )
                 {
                     SetRedlineText( STR_AUTOFMTREDL_CPTL_STT_SENT );
-                    pATst->FnCptlSttSntnc( aACorrDoc, *pText, true, nSttPos, nPos, eLang);
+                    pATst->FnCapitalStartSentence( aACorrDoc, *pText, true, nSttPos, nPos, eLang);
                 }
 
                 bFirst = bFirstSent;
diff --git a/sw/source/core/inc/acorrect.hxx b/sw/source/core/inc/acorrect.hxx
index 1f60018..4a833abf 100644
--- a/sw/source/core/inc/acorrect.hxx
+++ b/sw/source/core/inc/acorrect.hxx
@@ -80,7 +80,7 @@ public:
 
     // Will be called after swapping characters by the functions
     //  - FnCptlSttWrd and
-    //  - FnCptlSttSntnc.
+    //  - FnCapitalStartSentence.
     // Afterwards the words can be added into exception list if needed.
     virtual void SaveCpltSttWord( sal_uLong nFlag, sal_Int32 nPos,
                                     const OUString& rExceptWord, sal_Unicode cChar ) SAL_OVERRIDE;
diff --git a/sw/source/uibase/docvw/edtwin.cxx b/sw/source/uibase/docvw/edtwin.cxx
index 995c290..3db93d4 100644
--- a/sw/source/uibase/docvw/edtwin.cxx
+++ b/sw/source/uibase/docvw/edtwin.cxx
@@ -2393,7 +2393,7 @@ KEYINPUT_CHECKTABLE_INSDEL:
                 }
                 else if( !aKeyEvent.GetRepeat() && pACorr && ( bIsAutoCorrectChar || bRunNext ) &&
                         pACfg->IsAutoFormatByInput() &&
-                    pACorr->IsAutoCorrFlag( CptlSttSntnc | CptlSttWrd |
+                    pACorr->IsAutoCorrFlag( CapitalStartSentence | CptlSttWrd |
                                             ChgOrdinalNumber | AddNonBrkSpace |
                                             ChgToEnEmDash | SetINetAttr |
                                             Autocorrect ) &&
@@ -2427,7 +2427,7 @@ KEYINPUT_CHECKTABLE_INSDEL:
         case KS_CheckAutoCorrect:
         {
             if( pACorr && pACfg->IsAutoFormatByInput() &&
-                pACorr->IsAutoCorrFlag( CptlSttSntnc | CptlSttWrd |
+                pACorr->IsAutoCorrFlag( CapitalStartSentence | CptlSttWrd |
                                         ChgOrdinalNumber |
                                         ChgToEnEmDash | SetINetAttr |
                                         Autocorrect ) &&
diff --git a/sw/source/uibase/shells/textsh.cxx b/sw/source/uibase/shells/textsh.cxx
index 2cf10fe..3261a85 100644
--- a/sw/source/uibase/shells/textsh.cxx
+++ b/sw/source/uibase/shells/textsh.cxx
@@ -169,7 +169,7 @@ void SwTextShell::ExecInsert(SfxRequest &rReq)
             SvxAutoCorrect* pACorr = rACfg.GetAutoCorrect();
             if( pACorr && rACfg.IsAutoFormatByInput()
                 && pACorr->IsAutoCorrFlag(
-                    CptlSttSntnc | CptlSttWrd | AddNonBrkSpace | ChgOrdinalNumber | ChgToEnEmDash | SetINetAttr | Autocorrect ) )
+                    CapitalStartSentence | CptlSttWrd | AddNonBrkSpace | ChgOrdinalNumber | ChgToEnEmDash | SetINetAttr | Autocorrect ) )
             {
                 rSh.AutoCorrect( *pACorr, cIns );
             }
diff --git a/sw/source/uibase/wrtsh/wrtsh1.cxx b/sw/source/uibase/wrtsh/wrtsh1.cxx
index 08422c7..5d1c0d7 100644
--- a/sw/source/uibase/wrtsh/wrtsh1.cxx
+++ b/sw/source/uibase/wrtsh/wrtsh1.cxx
@@ -137,7 +137,7 @@ using namespace com::sun::star;
 static SvxAutoCorrect* lcl_IsAutoCorr()
 {
     SvxAutoCorrect* pACorr = SvxAutoCorrCfg::Get().GetAutoCorrect();
-    if( pACorr && !pACorr->IsAutoCorrFlag( CptlSttSntnc | CptlSttWrd |
+    if( pACorr && !pACorr->IsAutoCorrFlag( CapitalStartSentence | CptlSttWrd |
                             AddNonBrkSpace | ChgOrdinalNumber |
                             ChgToEnEmDash | SetINetAttr | Autocorrect ))
         pACorr = 0;


More information about the Libreoffice-commits mailing list
diff --git a/editeng/source/misc/svxacorr.cxx b/editeng/source/misc/svxacorr.cxx
index 77816d9..425e687 100644
--- a/editeng/source/misc/svxacorr.cxx
+++ b/editeng/source/misc/svxacorr.cxx
@@ -90,7 +90,7 @@ static const sal_Char
     /* also at these ends - Brackets and all kinds of begin characters */
     sImplEndSkipChars[] = "\"\')]}\x83\x84\x89\x91\x92\x93\x94";
 
 // These characters are allowed in words: (for FnCptlSttSntnc)
 static const sal_Char sImplWordChars[] = "-'";
 
 OUString EncryptBlockName_Imp(const OUString& rName);
@@ -175,7 +175,7 @@ SvxAutoCorrDoc::~SvxAutoCorrDoc()
 
 // Called by the functions:
 //  - FnCptlSttWrd
-//  - FnCptlSttSntnc
+//  - FnCapitalStartSentence
 // after the exchange of characters. Then the words, if necessary, can be inserted
 // into the exception list.
 void SvxAutoCorrDoc::SaveCpltSttWord( sal_uLong, sal_Int32, const OUString&,
@@ -250,7 +250,7 @@ bool SvxAutoCorrect::NeedsHardspaceAutocorr( sal_Unicode cChar )
 long SvxAutoCorrect::GetDefaultFlags()
 {
     long nRet = Autocorrect
-                    | CptlSttSntnc
+                    | CapitalStartSentence
                     | CptlSttWrd
                     | ChgOrdinalNumber
                     | ChgToEnEmDash
@@ -340,7 +340,7 @@ void SvxAutoCorrect::SetAutoCorrFlag( long nFlag, bool bOn )
 
     if( !bOn )
     {
-        if( (nOld & CptlSttSntnc) != (nFlags & CptlSttSntnc) )
+        if( (nOld & CapitalStartSentence) != (nFlags & CapitalStartSentence) )
             nFlags &= ~CplSttLstLoad;
         if( (nOld & CptlSttWrd) != (nFlags & CptlSttWrd) )
             nFlags &= ~WrdSttLstLoad;
@@ -800,7 +800,7 @@ bool SvxAutoCorrect::FnChgWeightUnderl( SvxAutoCorrDoc& rDoc, const OUString& rT
 }
 
 
-bool SvxAutoCorrect::FnCptlSttSntnc( SvxAutoCorrDoc& rDoc,
+bool SvxAutoCorrect::FnCapitalStartSentence( SvxAutoCorrDoc& rDoc,
                                     const OUString& rTxt, bool bNormalPos,
                                     sal_Int32 nSttPos, sal_Int32 nEndPos,
                                     LanguageType eLang )
@@ -1069,7 +1069,7 @@ bool SvxAutoCorrect::FnCptlSttSntnc( SvxAutoCorrDoc& rDoc,
 
     // Parahaps someone wants to have the word
     if( bRet && SaveWordCplSttLst & nFlags )
-        rDoc.SaveCpltSttWord( CptlSttSntnc, nSttPos, sWord, cSave );
+        rDoc.SaveCpltSttWord( CapitalStartSentence, nSttPos, sWord, cSave );
 
     return bRet;
 }
@@ -1335,7 +1335,7 @@ SvxAutoCorrect::DoAutoCorrect( SvxAutoCorrDoc& rDoc, const OUString& rTxt,
         if( IsAutoCorrFlag( Autocorrect ) )
         {
             OUString aPara;
-            OUString* pPara = IsAutoCorrFlag(CptlSttSntnc) ? &aPara : 0;
+            OUString* pPara = IsAutoCorrFlag(CapitalStartSentence) ? &aPara : 0;
 
             // since LibO 4.1, '-' is a word separator
             // fdo#67742 avoid "--" to be replaced by "–" if next is "-"
@@ -1375,10 +1375,10 @@ SvxAutoCorrect::DoAutoCorrect( SvxAutoCorrDoc& rDoc, const OUString& rTxt,
                         ++nEnd;
 
                     // Capital letter at beginning of paragraph?
-                    if( IsAutoCorrFlag( CptlSttSntnc ) &&
-                        FnCptlSttSntnc( rDoc, aPara, false,
+                    if( IsAutoCorrFlag( CapitalStartSentence ) &&
+                        FnCapitalStartSentence( rDoc, aPara, false,
                                                 nCapLttrPos, nEnd, eLang ) )
-                        nRet |= CptlSttSntnc;
+                        nRet |= CapitalStartSentence;
 
                     if( IsAutoCorrFlag( ChgToEnEmDash ) &&
                         FnChgToEnEmDash( rDoc, rTxt, nCapLttrPos, nEnd, eLang ) )
@@ -1414,9 +1414,9 @@ SvxAutoCorrect::DoAutoCorrect( SvxAutoCorrDoc& rDoc, const OUString& rTxt,
 
             // Capital letter at beginning of paragraph ?
             if( !bUnsupported &&
-                IsAutoCorrFlag( CptlSttSntnc ) &&
-                FnCptlSttSntnc( rDoc, rTxt, true, nCapLttrPos, nInsPos, eLang ) )
-                nRet |= CptlSttSntnc;
+                IsAutoCorrFlag( CapitalStartSentence ) &&
+                FnCapitalStartSentence( rDoc, rTxt, true, nCapLttrPos, nInsPos, eLang ) )
+                nRet |= CapitalStartSentence;
 
             // Two capital letters at beginning of word ??
             if( !bUnsupported &&
@@ -90,7 +90,7 @@ static const sal_Char
     sImplEndSkipChars[] = "\"\')]}\x83\x84\x89\x91\x92\x93\x94";
 
-// These characters are allowed in words: (for FnCptlSttSntnc)
+// These characters are allowed in words: (for FnCapitalStartSentence)
 static const sal_Char sImplWordChars[] = "-'";
 